@@ -301,7 +301,11 @@ class Model:
     def _get_signal_function(self, name, fun):
         def signal(d=None):
             if d is None or len(self.signals[name]) == 0 or np.isclose(d, 0.0):
-                value = fun()
+                try:
+                    value = fun()
+                except TypeError:
+                    self._l.error(f"TypeError in signal {name}")
+                    raise
             else:
                 value = self._delayed_signal_value(name, d)
             assert value is not None, "Value is not None."
